contexttools.ClefMarkInventory
==============================

.. abjad-lineage:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory

.. autoclass:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.append
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.count
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.extend
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.index
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.insert
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.item_class
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.name
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.new
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.pop
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.remove
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.reverse
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.sort
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.storage_format
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__contains__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__delitem__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__eq__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__getitem__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iadd__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iter__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__len__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__ne__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__repr__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__reversed__
      ~abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__setitem__

Bases
-----

- :py:class:`datastructuretools.TypedList <abjad.tools.datastructuretools.TypedList.TypedList.TypedList>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.item_class
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.append
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.count
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.extend
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.index
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.insert
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.new
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.pop
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.remove
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.reverse
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__len__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.contexttools.ClefMarkInventory.ClefMarkInventory.ClefMarkInventory.__setitem__
   :noindex:
